# Moved

This was a package for PrestoSQL. The package itself is no longer maintained,
as [PrestoSQL got renamed to Trino](https://trino.io/blog/2020/12/27/announcing-trino.html).

If you are using an older PrestoSQL release, you can install a previous
version of the package with:

    pip install presto-client==0.302.0
    
The package has been superseded with a client for [Trino (formerly Presto SQL)](https://trino.io).
You can install it with:

    pip install trino
    
Apologies for the disruption and very short notice, resulting in no transition
period.
